window.Gleam.initSearch([{"doc":"convert_json","title":"convert_json","content":"# convert_json\n\n[![Package Version](https://img.shields.io/hexpm/v/convert_json)](https://hex.pm/packages/convert_json)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/convert_json/)\n\n**Encode and decode JSON from and to Gleam types !**\n\nDefine a converter once and encode and decode as much as you want.\n\n## Installation\n\n```sh\ngleam add convert\ngleam add convert_json\n```\n\n## Usage\n\n```gleam\nimport gleam/io\nimport gleam/json\nimport convert as c\nimport convert/json as cjson\n\npub type Person {\n  Person(name: String, age: Int)\n}\n\npub fn main() {\n  let converter =\n    c.object({\n      use name &lt;- c.field(&quot;name&quot;, fn(v: Person) { Ok(v.name) }, c.string())\n      use age &lt;- c.field(&quot;age&quot;, fn(v: Person) { Ok(v.age) }, c.int())\n      c.success(Person(name:, age:))\n    })\n\n  Person(&quot;Anna&quot;, 21)\n  |&gt; cjson.json_encode(converter)\n  |&gt; json.to_string\n  |&gt; io.debug\n  // &#39;{&quot;name&quot;: &quot;Anna&quot;, &quot;age&quot;: 21}&#39;\n\n  &quot;{\\&quot;name\\&quot;: \\&quot;Bob\\&quot;, \\&quot;age\\&quot;: 36}&quot;\n  |&gt; json.decode(cjson.json_decode(converter))\n  |&gt; io.debug\n  // Ok(Person(&quot;Bob&quot;, 36))\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/convert_json&gt;.\n\n## Features\n\n- Encode and decode to JSON.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"convert/json","title":"decode_value","content":"pub fn decode_value(\n  of: GlitrType,\n) -&gt; fn(Dynamic) -&gt; Result(GlitrValue, List(DecodeError))\n Decode a JSON value using the specified GlitrType as the shape of the data.  \n Returns the corresponding GlitrValue representation.\n This isn&#39;t meant to be used directly !\nSynonyms:\nconvert/json.decode_value\nconvert/json decode_value","url":"convert/json.html#decode_value"},{"doc":"convert/json","title":"encode_value","content":"pub fn encode_value(val: GlitrValue) -&gt; Json\n Encode a GlitrValue into its corresponding JSON representation.  \n This is not meant to be used directly !  \n It is better to use converters.\nSynonyms:\nconvert/json.encode_value\nconvert/json encode_value","url":"convert/json.html#encode_value"},{"doc":"convert/json","title":"json_decode","content":"pub fn json_decode(\n  converter: Converter(a),\n) -&gt; fn(Dynamic) -&gt; Result(a, List(DecodeError))\n Decode a Json value using the provided converter.\nSynonyms:\nconvert/json.json_decode\nconvert/json json_decode","url":"convert/json.html#json_decode"},{"doc":"convert/json","title":"json_encode","content":"pub fn json_encode(value: a, converter: Converter(a)) -&gt; Json\n Encode a value into the corresponding Json using the converter.  \n If the converter isn&#39;t valid, a NullValue is returned.\nSynonyms:\nconvert/json.json_encode\nconvert/json json_encode","url":"convert/json.html#json_encode"},{"doc":"convert/json","title":"convert/json","content":"","url":"convert/json.html"}]);